@@ -63,11 +63,13 @@ void OnKoch()
     unsigned int startspeed = koch_sec->option("StartSpeed")->get();
     unsigned int skill = koch_sec->option("Skill")->get();
 
+    unsigned int next_difficulty = koch_sec->option("Difficulty")->get();
+    
     Dialog<bool> ask_exit_koch(dlg_koch_title, main_menu_prompt);
     ask_exit_koch.add_choice(dlg_koch_exit, false);
     ask_exit_koch.add_default_choice(dlg_koch_continue, true);
 
-    libexercises::Koch koch_exc(chars, strnum, strlen, skill);
+    libexercises::Koch koch_exc(chars, strnum, strlen, skill, next_difficulty);
 
     do
     {
@@ -87,19 +89,16 @@ void OnKoch()
 	sleep(beginpause);
 
 	if( check(koch_exc) >= 90)
-	{
 	    koch_exc.next();
-	    startspeed += 5;
-	}
 	else
 	    koch_exc.shuffle();
     }
     while(ask_exit_koch.show());
 
-    //save difficulty
+    //save exercise status
     koch_sec->option("Chars")->set(koch_exc.get_chars());
     koch_sec->option("StringsNumber")->set(koch_exc.strnum());
     koch_sec->option("StringLength")->set(koch_exc.strlen());
-    koch_sec->option("StartSpeed")->set(startspeed);
     koch_sec->option("Skill")->set(koch_exc.skill());
+    koch_sec->option("Difficulty")->set(koch_exc.difficulty());    
 }
