@@ -31,7 +31,6 @@
 #include "datafile.hh"
 #include "skill.hh"
 
-#include <iostream>
 #include <string>
 #include <cstdlib>
 
@@ -193,6 +192,8 @@ void OnKochConf()
     update_option(this_sec->option("StartSpeed"), insert_wpm);
 
     update_option(this_sec->option("Skill"), insert_pos);
+    
+    update_option(this_sec->option("Difficulty"), insert_pos);    
 }
 
 void OnQrzConf()
@@ -268,6 +269,9 @@ void OnResetDefault()
     koch_sec->add_option("Skill");
     koch_sec->option("Skill")->set(2);
 
+    koch_sec->add_option("Difficulty");
+    koch_sec->option("Difficulty")->set(0);
+    
     fileconf.add_section("Qrz");
     sec_it qrz_sec = fileconf.section("Qrz");
 
